# **T1-T2-ne**

This software computes the optimal delays for protein dynamics experiments.

Full documentation is available at [https://t1ttune.readthedocs.io/en/latest/](https://t1ttune.readthedocs.io/en/latest/).
